pro hydro_analytic,tmin,tmax,s_heat,s,t_s,p_s,n_s,radfunc,radref,eh0,$
	f_s,dptot,etot,a,b,theta,gamma,g_star
;
;	Analytical approximation of hydrostatic solutions 
;	Reference: Aschwanden,M.J. and Schrijver,C.J 2002,
;	The Astrophysical Journal Supplement Series, Vol. 142, p. 269-283
;	URL1="http://www.lmsal.com/~aschwand/eprints/2002_hydro.ps.gz"
;	Analytical Approximations to Hydrodynamic Solutions and Scaling Laws of Coronal Loops
;
;	See also documentation on web-site:
;	http://www.lmsal.com/~aschwand/hydro_software/hydro_tutorial1.html
;
;Written:
;	Markus J. Aschwanden, June 2001, aschwanden@lmsal.com (phone 650-424-4001)
;
;INPUT:
;	tmax [K]  		=loop top temperature at s(ns-1)=len
;	s(*) [cm]		=array with loop coordinate points, with loop half length len=max(s)
;	s_heat [cm]		=heating scale height
;	eh0 [erg cm-3 s-1]	=base heating rate
;
;INPUT OPTIONAL:
;	tmin [K]  		=footpoint temperature at s(0)
;	theta [deg]		=inclination angle of loop plane
;				 (defines effective gravity along loop: g_loop=g_vertical/cos(theta)
;	gamma			=loop expansion factor 
;	g_star			=ratio of surface gravity of star to sun (default=1)
;				 (see definitions in procedure RADIATIVE_LOSS.PRO)
;
;OUTPUT:
;	t_s(*) [K]		=array with temperatures T(s)     as function of loop coordinate s
;	p_s(*) [dyne]		=array with pressure p(s)         as function of loop coordinate s
;	n_s(*) [cm-3]		=array with electron density n(s) as function of loop coordinate s	
;	f_s(*) [cgs-units]	=conductive flux
;	dptot(*)		=array of momentum balance        as function of loop coordinate s	
;	etot(*)			=array of energy balance          as function of loop coordinate s	
;	a			=coefficient a of temperature approximation		
;	b			=coefficient b of temperature approximation		
;	radfunc			=radiative loss function (-1,0,1,...,6)
;	radref			=string containing reference of radiative loss function
;
;CALL OTHER ROUTINES:
;	RADIATIVE_LOSS.PRO
;	HYDRO_TMAX.PRO

;EAXMPLE 1: ____________________;(using [L, s_H, T_max] as independent variables)
;	tmin    =2.0e4		;[K] temperature of footpoint in transition region
;	tmax	=1.0e6		;[K] loop top temperature
;	len     =2.0e9		;[cm] loop half length     20,000 km
;	s_heat  =1.0e9		;[cm] heating scale height 10,000 km
;	h_chr   =1.3e8		;[cm] height of footpoint in transition region (1300 km)
;	ns      =200		;number of loop coordinates
;	s       =h_chr+(len-h_chr)*findgen(ns)/float(ns-1)	;loop coordinates
;	theta	=0.		;loop inclination angle
;	g_star	=1.		;surface gravity on star 
;	gamma	=1.		;loop expansion factor 
;	hydro_analytic,tmin,tmax,s_heat,s,t_s,p_s,n_s,radfunc,radref,eh0,f_s,dptot,etot,a,b
;	plot,s,t_s		;plot temperature profile
;	plot,s,p_s		;plot pressure profile
;	plot,s,n_s		;plot density profile
;	print,eh0		;--> E_H0=0.000682425 erg cm-s s-1
;
;EAXMPLE 2: ____________________;(using [L, s_H, E_H0] as independent variables)
;	(tmin,len,s_heat,h_chr,ns,s,radfunc defined in Example 1)
;	eh0	=0.0006825	;[erg cm-2 s-1] base heating rate
;	tmax	=hydro_tmax(eh0,s_heat,s) ;conversion of EH0-->Tmax [K] loop top temperature
;	hydro_analytic,tmin,tmax,s_heat,s,t_s,p_s,n_s,radfunc,radref,eh0,f_s,dptot,etot,a,b
;	print,tmax		;--> T_max=1.000e6 K 
;

if (n_params(1) le 15) then theta=0.	;inclination angle of loop plane
if (n_params(1) le 16) then gamma=1.	;loop expansion factor 
if (n_params(1) le 17) then g_star=1.	;ratio of surface gravity of star to that of sun
th	=!pi*(theta/180.)

;___________________________INTERPOLATION SCHEME_____________________
t_	=[1.,3.,5.,10.]*1.e6
a0_	=[ 2.098, 2.000, 2.055, 2.026]	&a0=spline(t_,a0_,tmax)
a1_	=[ 0.258, 0.343, 0.328, 0.298]	&a1=spline(t_,a1_,tmax)
a2_	=[ 1.565, 1.418, 1.649, 1.570]	&a2=spline(t_,a2_,tmax)
b0_	=[ 0.320, 0.323, 0.329, 0.309]	&b0=spline(t_,b0_,tmax)
b1_	=[-0.009,-0.008,-0.009,-0.009]	&b1=spline(t_,b1_,tmax)
b2_	=[ 0.877, 0.902, 0.852, 0.928]	&b2=spline(t_,b2_,tmax)
c0_	=[ 0.693, 0.699, 0.700, 0.707]	&c0=spline(t_,c0_,tmax)
c1_	=[ 0.026, 0.024, 0.014, 0.029]	&c1=spline(t_,c1_,tmax)
c2_	=[ 1.199, 1.240, 2.427, 0.915]	&c2=spline(t_,c2_,tmax)
d0_	=[ 1452., 1416., 1428., 1506.]  &d0=spline(t_,d0_,tmax)
d1_	=[-0.074,-0.087,-0.064,-0.036]  &d1=spline(t_,d1_,tmax)
d2_	=[-0.030,-0.044, 0.000, 0.001]  &d2=spline(t_,d2_,tmax)
d3_	=[-0.001,-0.003,-0.023,-0.021]  &d3=spline(t_,d3_,tmax)
d4_	=[ 0.015, 0.043, 0.010, 0.011]  &d4=spline(t_,d4_,tmax)
e0_	=[ 0.686, 0.831, 0.808, 0.707]*1.e-6  &e0=spline(t_,e0_,tmax)
e1_	=[ 0.558, 0.848, 0.847, 0.685]  &e1=spline(t_,e1_,tmax)
e2_	=[-0.423,-0.707,-0.634,-0.403]  &e2=spline(t_,e2_,tmax)
e3_	=[ 0.548, 0.057,-0.058, 0.063]  &e3=spline(t_,e3_,tmax)
e4_	=[ 0.156, 0.365, 0.361, 0.145]  &e4=spline(t_,e4_,tmax)

ns	=n_elements(s)
len	=s(ns-1)
t_s	=fltarr(ns)
p_s	=fltarr(ns)
n_s	=fltarr(ns)
f_s	=fltarr(ns)
dptot	=fltarr(ns)
etot	=fltarr(ns)
eh0	=0.
radfunc	=0		;radiative loss function from Rosner, Tucker & Vaiana (1978)
kappa   =9.2e-7         ;erg /s cm k^7/2
rsun	=6.96e10 	;cm
kb      =1.3807e-16	;erg/K
mu      =1.3
mp      =1.67e-24   	;g
g0_sun  =2.74e4     	;cm/s2
g0	=g_star*g0_sun*cos(th)		;effective gravity along loop 
lambda0	=2.*kb*1.e6/(mu*mp*g0)		;lambda0=4.64215e+09 scale height for 1 MK
len	=s(ns-1)	;cm
len0	=len-s(0)
s_p     =lambda0*(tmax/1.e6)
if (gamma le 1) then s_heat_eq=s_heat
if (gamma gt 1) then begin
 if (s_heat le len) then s_heat_eq=s_heat/sqrt(1.+(gamma-1.)*(s_heat/len)) 
 if (s_heat gt len) then s_heat_eq=(len/sqrt(gamma-1.))
endif
a	=a0+a1*(len0/s_heat_eq)^a2		
b	=b0+b1*(len0/s_heat_eq)^b2
qlambda	=c0+c1*(len0/s_heat_eq)^c2
const1  =d0*(exp(d1*len0/s_heat_eq+d2*len0/s_p)+d3*len0/s_heat_eq+d4*len0/s_p)
const2  =e0*(exp(e1*len0/s_heat_eq+e2*len0/s_p)+e3*len0/s_heat_eq+e4*len0/s_p)
p0	=(1./len0)*(tmax/const1)^3.
eh0	=tmax^(3.5)*len0^(-2.)*const2
z	=(len-s)/len0
t_s   	=tmax*(1.-z^a*(1.-(tmin/tmax)^(1./b)))^b	
if (s_heat_eq/len lt 1./3.) then begin
 t_s=t_s*(1.+0.5*alog10(len0/s_heat_eq)*(1-z)*z^5)
 print,'Temperature maximum not at loop top!'
endif
t_s(0)  =tmin
t_s(ns-1)=tmax
h1	=2.*len/!pi
h_s	=h1*sin(s/h1)
l_s	=lambda0*(t_s/1.e6)*(1.+h_s/rsun)*qlambda	
p_s	=p0*exp(-(h_s-h_s(0))/l_s)
n_s	=p_s/(2.*kb*t_s)
f_s 	=-kappa*t_s^2.5*deriv(s,t_s)
v_s   	=s*0.
if (gamma eq 1.) then area=s*0.+1.
if (gamma gt 1.) then begin
 s_sub=len/((!pi/(2.*asin(1./sqrt(gamma))))-1.)
 phi    =(!pi/2.)*(s+s_sub)/(len+s_sub)
 area   =gamma*sin(phi)^2
 da_ds  =gamma*2.*sin(phi)*cos(phi)*(!pi/2.)/(len+s_sub)
endif
if (gamma le 1) then df_ds=deriv(s,f_s)
if (gamma gt 1) then df_ds=deriv(s,f_s*area)/area
dv_ds   =deriv(s,v_s)
dp_ds	=deriv(s,p_s)
dpgrav	=-mu*mp*n_s*g0*(rsun/(rsun+h_s))^2*abs(cos(s/h1))
dptot	=-dp_ds+dpgrav
econd	=df_ds
erad	=radiative_loss(t_s,n_s,radfunc,radref)
eheat   =eh0*exp(-(s-s(0))/s_heat)
etot	=-econd+eheat+erad

end
