pro hydro_numeric_func,tmin,p0,e0,s_heat,s,te,p,n,f,radfunc
;
;PURPOSE:
;	This is a low-level routine called by HYDRO_NUMERIC.PRO.
;	It calculates hydrostatic temperature T(s) and pressure profiles p(s)
;	for an adaptive (non-equidistant gris s(ns) between H_CHR < s < LEN) 
;	that fulfil momentum and energy equation for a specified base 
;	pressure p0 and base heating rate EH0. For a full hydrostatic
;	solutions, p0 and EH0 need to be varied to match boundary conditions
;	T_max=T(s=L), and F_C(s=L)=0 (use higher-level routine HYDRO_NUMERIC.PRO)
;INPUT:
;	tmin [K]  		=footpoint temperature at s(0)
;	p0 [dyne]  		=base pressure at s(0)
;	e0  [erg cm-3 s-1]	=base heating rate
;	s_heat [cm]		=heating scale height
;	s(*) [cm]		=array with loop coordinate points, with loop half length len=max(s)
;	radfunc			=version number of radiative loss function (RADIATIVE_LOSS.PRO) 
;OUTPUT:
;	te(*) [K]		=array with temperatures T(s)     as function of loop coordinate s
;	p(*) [dyne]		=array with pressure p(s)         as function of loop coordinate s
;	n(*) [cm-3]		=array with electron density n(s) as function of loop coordinate s	
;	f(*) [cm-3]		=array with conductive flux f(s)  as function of loop coordinate s	
;Written:
;	Markus J. Aschwanden, May 2001, aschwanden@lmsal.com (phone 650-424-4001)

ns	=n_elements(s)
te      =fltarr(ns)
n       =fltarr(ns)
p       =fltarr(ns)
f       =fltarr(ns)
eheat   =e0*exp(-s/s_heat)
lambda0	=4.6e9		;cm
rsun	=6.96e10	;cm
kb	=1.3807e-16     ;erg/K
kappa   =9.2e-7     	;erg /s cm k^7/2
len	=s(ns-1)
h	=(2.*len/!pi)*sin(!pi*s/(2.*len))
ds	=s(1)-s(0)	
te(0)	=tmin
p(0)	=p0
n(0)	=p(0)/(2.*kb*te(0))
erad0   =radiative_loss(te(0),n(0),radfunc,radref)
a	=-(7./(4.*kappa))*(eheat(0)+erad0)
s0	=s(0)
y0	=te(0)^3.5
te(1)	=(te(0)^3.5+a*ds^2)^(2./7.)
p(1)	=p(0)*exp(-(h(1)-h(0))/(lambda0*(tmin/1.e6)))
n(1)	=p(1)/(2.*kb*te(1))
for is=2,ns-1 do begin
 h1	=h(is-2)
 h2	=h(is-1)
 h3	=h(is)
 p1	=p(is-2)
 p2	=p(is-1)
 t1	=te(is-2)
 t2	=te(is-1)
 n1	=n(is-2)
 n2	=n(is-1)
 s1	=s(is-2)
 s2	=s(is-1)
 s3	=s(is)
 y1	=te(is-2)^3.5
 y2	=te(is-1)^3.5
 erad2  =radiative_loss(t2,n2,radfunc,radref)
 eheat2	=eheat(is-1)
 a	=-(7./(4.*kappa))*(eheat2+erad2)
 s0	=0.5*(s2+s1-(1./a)*(y2-y1)/(s2-s1))
 y0	=y1-a*(s1-s0)^2
 y3	=y0+a*(s3-s0)^2
 if (y3(0) gt 0) then te(is) =y3^(2./7.)
 if (y3(0) le 0) then te(is) =tmin
 lam1	=lambda0*(t1/1.e6)*(1.+h1/rsun)^2
 lam2	=lambda0*(t2/1.e6)*(1.+h2/rsun)^2
 lam3	=2.*lam2-lam1
 p(is)	=p2*exp(-(h3-h2)/lam3)
 n(is)  =p(is)/(2.*kb*te(is))
endfor
f       =-kappa*te^2.5*deriv(s,te)
end
